@@ -28,7 +28,7 @@
 
 #ifndef _GNUstep_H_NSAlert
 #define _GNUstep_H_NSAlert
-#import <GNUstepBase/GSVersionMacros.h>
+#import <AppKit/AppKitDefines.h>
 
 #import <Foundation/NSObject.h>
 
@@ -55,6 +55,7 @@ enum {
   NSAlertThirdButtonReturn = 1002
 };
 
+APPKIT_EXPORT_CLASS
 @interface NSAlert : NSObject 
 {
   @private
@@ -112,8 +113,14 @@ enum {
  * Implemented by the delegate
  */
 
-#ifdef GNUSTEP
+#if OS_API_VERSION(GS_API_MACOSX, GS_API_LATEST)
+@protocol NSAlertDelegate <NSObject>
+#if OS_API_VERSION(MAC_OS_X_VERSION_10_6, GS_API_LATEST) && GS_PROTOCOLS_HAVE_OPTIONAL
+@optional
+#else
+@end
 @interface NSObject (NSAlertDelegate)
+#endif
 - (BOOL) alertShowHelp: (NSAlert *)alert;
 @end
 #endif
