@@ -1,7 +1,7 @@
 /* 
    NSMatrix.h
 
-   Copyright (C) 1996,1997,1999 Free Software Foundation, Inc.
+   Copyright (C) 1996-2015 Free Software Foundation, Inc.
 
    Author:  Ovidiu Predescu <ovidiu@net-community.com>
    Date: March 1997
@@ -29,7 +29,7 @@
 
 #ifndef _GNUstep_H_NSMatrix
 #define _GNUstep_H_NSMatrix
-#import <GNUstepBase/GSVersionMacros.h>
+#import <AppKit/AppKitDefines.h>
 
 #import <AppKit/NSControl.h>
 
@@ -49,14 +49,18 @@ typedef enum _NSMatrixMode {
   NSTrackModeMatrix 
 } NSMatrixMode;
 
+@protocol NSMatrixDelegate <NSControlTextEditingDelegate>
+@end
+
+APPKIT_EXPORT_CLASS
 @interface NSMatrix : NSControl <NSCoding>
 {
   __strong id		**_cells;
   BOOL		**_selectedCells;
-  int		_maxRows;
-  int		_maxCols;
-  int		_numRows;
-  int		_numCols;
+  NSInteger	_maxRows;
+  NSInteger	_maxCols;
+  NSInteger	_numRows;
+  NSInteger	_numCols;
   NSZone	*_myZone;
   Class		_cellClass;
   id		_cellPrototype;
@@ -75,8 +79,8 @@ typedef enum _NSMatrixMode {
   SEL		_doubleAction;
   SEL		_errorAction;
   id		_selectedCell;
-  int		_selectedRow;
-  int		_selectedColumn;
+  NSInteger	_selectedRow;
+  NSInteger	_selectedColumn;
   BOOL		_allowsEmptySelection;
   BOOL		_selectionByRect;
   BOOL		_drawsBackground;
@@ -84,8 +88,8 @@ typedef enum _NSMatrixMode {
   BOOL		_autosizesCells;
   BOOL		_autoscroll;
   id            _reserved1;
-  int		_dottedRow;
-  int		_dottedColumn;
+  NSInteger	_dottedRow;
+  NSInteger	_dottedColumn;
 }
 
 /*
@@ -304,6 +308,12 @@ typedef enum _NSMatrixMode {
  */
 - (void) resetCursorRects;
 
+/*
+ * Handling tool tips
+ */
+- (NSString *) toolTipForCell: (NSCell *)cell;
+- (void) setToolTip: (NSString *)toolTipString forCell: (NSCell *)cell;
+
 @end
 
 #endif /* _GNUstep_H_NSMatrix */
