@@ -35,7 +35,7 @@
 
 #ifndef _GNUstep_H_NSWindow
 #define _GNUstep_H_NSWindow
-#import <GNUstepBase/GSVersionMacros.h>
+#import <AppKit/AppKitDefines.h>
 
 #import <AppKit/NSGraphicsContext.h>
 #import <AppKit/NSResponder.h>
@@ -62,6 +62,7 @@
 @class NSView;
 @class NSWindowController;
 @class NSCachedImageRep;
+@class NSViewController;
 
 @class GSWindowDecorationView;
 
@@ -76,7 +77,7 @@
 enum {
   NSDesktopWindowLevel = -1000,	/* GNUstep addition	*/ // 2
   NSNormalWindowLevel = 0, // 3
-  NSFloatingWindowLevel = 3, // 4
+  NSFloatingWindowLevel = 2, // 4
   NSSubmenuWindowLevel = 3, // 5
   NSTornOffMenuWindowLevel = 3, // 5
   NSMainMenuWindowLevel = 20, // 7
@@ -87,22 +88,87 @@ enum {
   NSScreenSaverWindowLevel = 1000  // 12
 };
 
+#if OS_API_VERSION(MAC_OS_X_VERSION_10_9, GS_API_LATEST)
+enum {
+  NSModalResponseOK = 1,
+  NSModalResponseCancel = 0
+};
+#endif
+
 enum {
   NSBorderlessWindowMask = 0,
   NSTitledWindowMask = 1,
-  NSClosableWindowMask = 2,
-  NSMiniaturizableWindowMask = 4,
-  NSResizableWindowMask = 8,
+  NSClosableWindowMask = 1 << 1,
+  NSMiniaturizableWindowMask = 1 << 2,
+  NSResizableWindowMask = 1 << 3,
 #if OS_API_VERSION(MAC_OS_X_VERSION_10_2, GS_API_LATEST)
-  NSTexturedBackgroundWindowMask = 256,
+  NSTexturedBackgroundWindowMask = 1 << 8,
 #endif 
 #if OS_API_VERSION(MAC_OS_X_VERSION_10_4, GS_API_LATEST)
-  NSUnscaledWindowMask = 2048,
-  NSUnifiedTitleAndToolbarWindowMask = 4096,
-#endif 
+  NSUnscaledWindowMask = 1 << 11,
+  NSUnifiedTitleAndToolbarWindowMask = 1 << 12,
+#endif
+#if OS_API_VERSION(MAC_OS_X_VERSION_10_6, GS_API_LATEST)
+  NSWindowStyleMaskHUDWindow = 1 << 13,
+#endif
+#if OS_API_VERSION(MAC_OS_X_VERSION_10_7, GS_API_LATEST)
+  NSFullScreenWindowMask = 1 << 14,
+#endif
+#if OS_API_VERSION(MAC_OS_X_VERSION_10_10, GS_API_LATEST)
+  NSFullSizeContentViewWindowMask = 1 << 15,
+#endif
+#if OS_API_VERSION(MAC_OS_X_VERSION_10_12, GS_API_LATEST)
+  NSWindowStyleMaskBorderless = NSBorderlessWindowMask,
+  NSWindowStyleMaskTitled = NSTitledWindowMask,
+  NSWindowStyleMaskClosable = NSClosableWindowMask,
+  NSWindowStyleMaskMiniaturizable = NSMiniaturizableWindowMask,
+  NSWindowStyleMaskResizable = NSResizableWindowMask,
+  NSWindowStyleMaskUtilityWindow = 1 << 4,
+  NSWindowStyleMaskDocModalWindow = 1 << 6,
+  // Specifies that a panel that does not activate the owning application
+  NSWindowStyleMaskNonactivatingPanel = 1 << 7,
+  NSWindowStyleMaskTexturedBackground = NSTexturedBackgroundWindowMask,
+  NSWindowStyleMaskUnifiedTitleAndToolbar = NSUnifiedTitleAndToolbarWindowMask,
+  NSWindowStyleMaskFullScreen = NSFullScreenWindowMask,
+  NSWindowStyleMaskFullSizeContentView = NSFullSizeContentViewWindowMask,
+#endif
   NSIconWindowMask = 64,	/* GNUstep extension - app icon window	*/
   NSMiniWindowMask = 128	/* GNUstep extension - miniwindows	*/
 };
+typedef NSUInteger NSWindowStyleMask;
+
+#if OS_API_VERSION(MAC_OS_X_VERSION_10_5, GS_API_LATEST)
+enum {
+  NSWindowCollectionBehaviorDefault = 0,
+  NSWindowCollectionBehaviorCanJoinAllSpaces = 1 << 0,
+  NSWindowCollectionBehaviorMoveToActiveSpace = 1 << 1
+};
+#endif
+#if OS_API_VERSION(MAC_OS_X_VERSION_10_6, GS_API_LATEST)
+enum {
+  NSWindowCollectionBehaviorManaged = 1 << 2,
+  NSWindowCollectionBehaviorTransient = 1 << 3,
+  NSWindowCollectionBehaviorStationary = 1 << 4,
+};
+enum {
+  NSWindowCollectionBehaviorParticipatesInCycle = 1 << 5,
+  NSWindowCollectionBehaviorIgnoresCycle = 1 << 6
+};
+#endif
+#if OS_API_VERSION(MAC_OS_X_VERSION_10_7, GS_API_LATEST)
+enum {
+  NSWindowCollectionBehaviorFullScreenPrimary = 1 << 7,
+  NSWindowCollectionBehaviorFullScreenAuxiliary = 1 << 8
+};
+#endif
+#if OS_API_VERSION(MAC_OS_X_VERSION_10_11, GS_API_LATEST)
+enum
+{
+  NSWindowCollectionBehaviorFullScreenAllowsTiling = 1 << 11,
+  NSWindowCollectionBehaviorFullScreenDisallowsTiling = 1 << 12
+};
+#endif
+typedef NSUInteger NSWindowCollectionBehavior;
 
 enum _NSSelectionDirection {
   NSDirectSelection,
@@ -121,7 +187,7 @@ enum _NSWindowButton
   NSWindowDocumentIconButton
 };
 typedef NSUInteger NSWindowButton;
-#endif 
+#endif
 
 APPKIT_EXPORT NSSize NSIconSize;
 APPKIT_EXPORT NSSize NSTokenSize;
@@ -161,6 +227,7 @@ APPKIT_EXPORT NSSize NSTokenSize;
  * -convertBaseToScreen: and -convertScreenToBase: methods.
  * </p>
  */
+APPKIT_EXPORT_CLASS
 @interface NSWindow : NSResponder <NSCoding>
 {
   NSRect        _frame;
@@ -271,6 +338,14 @@ PACKAGE_SCOPE
  * Computing frame and content rectangles
  */
 
+/**
+ * Returns a window with the view of the specified viewController as it's
+ * content view.  The window is resizable, titled, closable, and miniaturizable.
+ */
+#if OS_API_VERSION(MAC_OS_X_VERSION_10_10, GS_API_LATEST)
++ (instancetype) windowWithContentViewController: (NSViewController *)viewController;
+#endif
+
 /**
  * Returns the rectangle which would be used for the content view of
  * a window whose on-screen size and position is specified by aRect
@@ -463,6 +538,7 @@ PACKAGE_SCOPE
 - (void) orderWindow: (NSWindowOrderingMode)place
 	  relativeTo: (NSInteger)otherWin;
 - (BOOL) isVisible;
+- (void) setIsVisible: (BOOL)flag;
 - (NSInteger) level;
 - (void) setLevel: (NSInteger)newLevel;
 
@@ -540,6 +616,11 @@ PACKAGE_SCOPE
 
 - (NSResponder*) firstResponder;
 
+#if OS_API_VERSION(MAC_OS_X_VERSION_10_5, GS_API_LATEST)
+- (NSWindowCollectionBehavior)collectionBehavior;
+- (void)setCollectionBehavior:(NSWindowCollectionBehavior)props;
+#endif
+
 /**
  * This method attempts to make aResponder the first responder.<br />
  * If aResponder is already the first responder, this method has no
@@ -737,7 +818,7 @@ PACKAGE_SCOPE
 #endif
 
 /*
- * Window butons
+ * Window buttons
  */
 #if OS_API_VERSION(MAC_OS_X_VERSION_10_2, GS_API_LATEST)
 + (NSButton *) standardWindowButton: (NSWindowButton)button 
@@ -773,6 +854,27 @@ PACKAGE_SCOPE
 - (void) setDisplaysWhenScreenProfileChanges: (BOOL)flag;
 #endif
 
+#if OS_API_VERSION(MAC_OS_X_VERSION_10_9, GS_API_LATEST)
+#if GS_HAS_DECLARED_PROPERTIES
+@property (readonly) NSWindow *sheetParent;
+#else
+- (NSWindow *) sheetParent;
+#endif
+#endif
+
+#if OS_API_VERSION(MAC_OS_X_VERSION_10_7, GS_API_LATEST)
+#if GS_HAS_DECLARED_PROPERTIES
+@property (readonly) CGFloat backingScaleFactor;
+#else
+- (CGFloat) backingScaleFactor;
+#endif
+#endif
+
+#if OS_API_VERSION(MAC_OS_X_VERSION_10_5, GS_API_LATEST)
++ (NSInteger)windowNumberAtPoint:(NSPoint)point
+     belowWindowWithWindowNumber:(NSInteger)windowNumber;
+#endif
+
 @end
 
 @class NSToolbar;
@@ -824,10 +926,9 @@ PACKAGE_SCOPE
  * Implemented by the delegate
  */
 
-#ifdef GNUSTEP
-
+#if OS_API_VERSION(GS_API_MACOSX, GS_API_LATEST)
 @protocol NSWindowDelegate <NSObject>
-#ifdef __OBJC2__ 
+#if OS_API_VERSION(MAC_OS_X_VERSION_10_6, GS_API_LATEST) && GS_PROTOCOLS_HAVE_OPTIONAL
 @optional
 #else
 @end
