@@ -24,8 +24,8 @@
    Boston, MA 02110-1301, USA.
 */ 
 
-#include "GSKeyBindingAction.h"
-#include "AppKit/NSInputManager.h"
+#import "AppKit/NSInputManager.h"
+#import "GSKeyBindingAction.h"
 
 @implementation GSKeyBindingAction
 - (void) performActionWithInputManager: (NSInputManager *)manager
@@ -63,7 +63,7 @@
   
   _selectorsCount = [sels count];
 
-  _selectors = objc_malloc (sizeof (SEL) * _selectorsCount);
+  _selectors = malloc (sizeof (SEL) * _selectorsCount);
 
   for (i = 0; i < _selectorsCount; i++)
     {
@@ -84,7 +84,7 @@
 
 - (void) dealloc
 {
-  objc_free (_selectors);
+  free (_selectors);
   [super dealloc];
 }
 
