@@ -52,6 +52,7 @@
 
 #import "GNUstepGUI/GSNibLoading.h"
 #import "AppKit/NSApplication.h"
+#import "AppKit/NSFontManager.h"
 #import "AppKit/NSImage.h"
 #import "AppKit/NSMenuItem.h"
 #import "AppKit/NSMenuView.h"
@@ -326,10 +327,12 @@ static BOOL _isInInterfaceBuilder = NO;
           _flags.isDeferred = deferred;
           _flags.isOneShot = oneShot;
           _flags.isVisible = visible;
+          _flags.isNotShadowed = ![window hasShadow];
           _flags.wantsToBeColor = wantsToBeColor;
           _flags.dynamicDepthLimit = [window hasDynamicDepthLimit];
           _flags.autoPositionMask = autoPositionMask;
           _flags.savePosition = YES; // not yet implemented.
+          _flags.autorecalculatesKeyViewLoop = [window autorecalculatesKeyViewLoop];
         }
     }
   return self;
@@ -343,14 +346,26 @@ static BOOL _isInInterfaceBuilder = NO;
         {
           ASSIGN(_viewClass, [coder decodeObjectForKey: @"NSViewClass"]);
         }
+      else
+        {
+          ASSIGN(_viewClass, @"NSView");
+        }
       if ([coder containsValueForKey: @"NSWindowClass"])
         {
           ASSIGN(_windowClass, [coder decodeObjectForKey: @"NSWindowClass"]);
         }
+      else
+        {
+          ASSIGN(_windowClass, @"NSWindow");
+        }
       if ([coder containsValueForKey: @"NSWindowStyleMask"])
         {
           _windowStyle = [coder decodeIntForKey: @"NSWindowStyleMask"];
         }
+      else
+        {
+          _windowStyle = 0;
+        }
       if ([coder containsValueForKey: @"NSWindowBacking"])
         {
           _backingStoreType = [coder decodeIntForKey: @"NSWindowBacking"];
@@ -409,6 +424,11 @@ static BOOL _isInInterfaceBuilder = NO;
           _windowStyle |= NSTitledWindowMask;
         }
 
+      if ([coder containsValueForKey: @"NSToolbar"])
+        {
+          _toolbar = [coder decodeObjectForKey: @"NSToolbar"];
+        }
+
       _baseWindowClass = [NSWindow class];
     }
   else
@@ -440,6 +460,7 @@ static BOOL _isInInterfaceBuilder = NO;
       [aCoder encodeRect: rect forKey: @"NSWindowRect"];
       [aCoder encodeObject: _title forKey: @"NSWindowTitle"];
       [aCoder encodeObject: _autosaveName forKey: @"NSFrameAutosaveName"];
+      [aCoder encodeObject: _toolbar forKey: @"NSToolbar"];
     }
 }
 
@@ -485,6 +506,8 @@ static BOOL _isInInterfaceBuilder = NO;
       // [_realObject setAutoPosition: _flags.autoPosition];
       [_realObject setDynamicDepthLimit: _flags.dynamicDepthLimit];
       // [_realObject setFrameAutosaveName: _autosaveName]; // done after setting the min/max sizes
+      [_realObject setHasShadow: !_flags.isNotShadowed];
+      [_realObject setAutorecalculatesKeyViewLoop: _flags.autorecalculatesKeyViewLoop];
 
       // reset attributes...
       [_realObject setContentView: _view];
@@ -497,6 +520,10 @@ static BOOL _isInInterfaceBuilder = NO;
           // FIXME: No idea what is going on here
 	  [_realObject setToolbar: (NSToolbar*)_viewClass];
 	}
+      if (_toolbar)
+        {
+          [_realObject setToolbar: _toolbar];
+        }
 
       [_realObject setContentMinSize: _minSize];
       [_realObject setContentMaxSize: _maxSize];
@@ -1001,9 +1028,14 @@ static BOOL _isInInterfaceBuilder = NO;
 
       if (GSObjCIsKindOf(aClass, [NSApplication class]) || 
 	 [_className isEqual: @"NSApplication"])
-	{
+        {
 	  _object = RETAIN([aClass sharedApplication]);
-	}
+        }
+      else if ((GSObjCIsKindOf(aClass, [NSFontManager class])) ||
+               ([_className isEqual: @"NSFontManager"]))
+        {
+          _object = RETAIN([aClass sharedFontManager]);
+        }
       else
 	{
 	  _object = [[aClass allocWithZone: NSDefaultMallocZone()] init];
