@@ -695,6 +695,13 @@
   [connection establishConnection];
 }
 
+- (NSString *) description
+{
+  return [NSString stringWithFormat: @"<%@ - %d, %@>", [super description],
+                   connectionID,
+                   connection];
+}
+
 @end
 
 @implementation IBToolTipAttribute
@@ -1039,6 +1046,12 @@
   NSEnumerator *en;
   id obj;
 
+  // If we are currently in IB, then don't do anything.
+  if ([NSClassSwapper isInInterfaceBuilder])
+    {
+      return self;
+    }
+
   // iterate over connections, instantiate, and then establish them.
   en = [connectionRecords objectEnumerator];
   while ((obj = [en nextObject]) != nil)
