@@ -30,7 +30,7 @@
 #ifndef _NSBitmapImageRep_PNG_H_include
 #define _NSBitmapImageRep_PNG_H_include
 
-#include "AppKit/NSBitmapImageRep.h"
+#import "AppKit/NSBitmapImageRep.h"
 
 @interface NSBitmapImageRep (PNG)
 + (BOOL) _bitmapIsPNG: (NSData *)imageData;
