@@ -61,25 +61,25 @@ static inline NSRect integralRect (NSRect rect, NSView *view)
   output = [view convertRect: rect  toView: nil];
 
   rounded = (int)(output.origin.x);
-  if ((float)rounded != output.origin.x)
+  if ((CGFloat)rounded != output.origin.x)
     {
       output.origin.x = rounded + 1;
     }
 
   rounded = (int)(output.origin.y);
-  if ((float)rounded != output.origin.y)
+  if ((CGFloat)rounded != output.origin.y)
     {
       output.origin.y = rounded + 1;
     }
   
   rounded = (int)(NSMaxX (output));
-  if ((float)rounded != NSMaxX (output))
+  if ((CGFloat)rounded != NSMaxX (output))
     {
       output.size.width = rounded - output.origin.x;
     }
   
   rounded = (int)(NSMaxY (output));
-  if ((float)rounded != NSMaxY (output))
+  if ((CGFloat)rounded != NSMaxY (output))
     {
       output.size.height = rounded - output.origin.y;
     }
@@ -125,6 +125,7 @@ static inline NSRect integralRect (NSRect rect, NSView *view)
 - (void) setDocumentView: (NSView*)aView
 {
   NSNotificationCenter	*nc;
+  NSView		*nextKV;
 
   if (_documentView == aView)
     {
@@ -134,6 +135,12 @@ static inline NSRect integralRect (NSRect rect, NSView *view)
   nc = [NSNotificationCenter defaultCenter];
   if (_documentView)
     {
+      nextKV = [_documentView nextKeyView];
+      if ([nextKV isDescendantOf: _documentView])
+	{
+	  nextKV = nil;
+	}
+
       [nc removeObserver: self
 	  name: NSViewFrameDidChangeNotification
 	  object: _documentView];
@@ -152,6 +159,10 @@ static inline NSRect integralRect (NSRect rect, NSView *view)
 	}
       [_documentView removeFromSuperview];
     }
+  else
+    {
+      nextKV = [self nextKeyView];
+    }
 
   /* Don't retain this since it's stored in our subviews. */
   _documentView = aView;
@@ -162,23 +173,13 @@ static inline NSRect integralRect (NSRect rect, NSView *view)
 
   if (_documentView)
     {
-      NSRect	df;
+      NSRect df;
 
       [self addSubview: _documentView];
 
       df = [_documentView frame];
       [self setBoundsOrigin: df.origin];
 
-      if ([aView respondsToSelector: @selector(backgroundColor)])
-	{
-	  [self setBackgroundColor: [(id)aView backgroundColor]];
-	}
-      
-      if ([aView respondsToSelector: @selector(drawsBackground)])
-	{
-	  [self setDrawsBackground: [(id)aView drawsBackground]];
-	}
-
       /* Register for notifications sent by the document view */
       [_documentView setPostsFrameChangedNotifications: YES];
       [_documentView setPostsBoundsChangedNotifications: YES];
@@ -193,7 +194,7 @@ static inline NSRect integralRect (NSRect rect, NSView *view)
 	       object: _documentView];
 
       /*
-       *  if out document view is a tableview, let it know
+       *  if our document view is a tableview, let it know
        *  when we resize
        */
       if ([_documentView isKindOfClass: [NSTableView class]])
@@ -205,9 +206,12 @@ static inline NSRect integralRect (NSRect rect, NSView *view)
 	           object: self];
 	}
 
+      [self setNextKeyView: _documentView];
+      if (![_documentView nextKeyView])
+	[_documentView setNextKeyView: nextKV];
     }
-
-  /* TODO: Adjust the key view loop to include the new document view */
+  else
+    [self setNextKeyView: nextKV];
 
   [_super_view reflectScrolledClipView: self];
 }
@@ -225,15 +229,15 @@ static inline NSRect integralRect (NSRect rect, NSView *view)
 
 - (void) setBounds: (NSRect)b
 {
-  // FIXME: Shouldn't the document view be marked as needing a redraw?
   [super setBounds: b];
+  [self setNeedsDisplay: YES];
   [_super_view reflectScrolledClipView: self];
 }
 
 - (void) setBoundsSize: (NSSize)aSize
 {
-  // FIXME: Shouldn't the document view be marked as needing a redraw?
   [super setBoundsSize: aSize];
+  [self setNeedsDisplay: YES];
   [_super_view reflectScrolledClipView: self];
 }
 
@@ -255,15 +259,12 @@ static inline NSRect integralRect (NSRect rect, NSView *view)
       return;
     }
       
-  // FIXME: Re-enable after release
-  if (NO) //_copiesOnScroll && _window && [_window gState])
+  if (_copiesOnScroll && _window && [_window gState])
     {
       /* Copy the portion of the view that is common before and after
          scrolling.  Then, document view needs to redraw the remaining
          areas. */
 
-	
-
       /* Common part - which is a first approx of what we could
          copy... */
       intersection = NSIntersectionRect (originalBounds, newBounds);
@@ -296,8 +297,8 @@ static inline NSRect integralRect (NSRect rect, NSView *view)
              origins, both of which should be integers in device space
              because of the code at the end of
              constrainScrollPoint:. */
-          float dx = newBounds.origin.x - originalBounds.origin.x;
-          float dy = newBounds.origin.y - originalBounds.origin.y;
+          CGFloat dx = newBounds.origin.x - originalBounds.origin.x;
+          CGFloat dy = newBounds.origin.y - originalBounds.origin.y;
           NSRect redrawRect;
                     
           /* Copy the intersection to the new position */
@@ -425,28 +426,11 @@ static inline NSRect integralRect (NSRect rect, NSView *view)
      do the scrolling, the difference is an integer and so we can copy
      the image translating it by an integer in device space - and not
      by a float. */
-  /*
+  
   new = [self convertPoint: new  toView: nil];
-  new.x = (int)new.x;
-  new.y = (int)new.y;
+  new.x = GSRoundTowardsInfinity(new.x);
+  new.y = GSRoundTowardsInfinity(new.y);
   new = [self convertPoint: new  fromView: nil];
-  */
-
-  /*
-     We don't make it an integer this way anymore.
-     This is not needed when _copiesOnScroll is not set.
-     If _copiesOnScroll is set, we make sure the difference between old
-     position and new position is an integer so we can copy the image 
-     easily. 
-     FIXME: Why should this help? If the value is integral in user space this does 
-     not mean anything in device space.
-  */
-  if (_copiesOnScroll)
-    {
-      new.x = _bounds.origin.x + (GSRoundTowardsInfinity(new.x - _bounds.origin.x));
-      new.y = _bounds.origin.y + (GSRoundTowardsInfinity(new.y - _bounds.origin.y));
-    }
-
   return new;
 }
 
@@ -664,7 +648,6 @@ static inline NSRect integralRect (NSRect rect, NSView *view)
 	  _isOpaque = YES;
 	}
     }
-  
 }
 
 - (void) setDrawsBackground: (BOOL)flag
@@ -703,15 +686,15 @@ static inline NSRect integralRect (NSRect rect, NSView *view)
 }
 
 /* Disable rotation of clip view */
-- (void) rotateByAngle: (float)angle
+- (void) rotateByAngle: (CGFloat)angle
 {
 }
 
-- (void) setBoundsRotation: (float)angle
+- (void) setBoundsRotation: (CGFloat)angle
 {
 }
 
-- (void) setFrameRotation: (float)angle
+- (void) setFrameRotation: (CGFloat)angle
 {
 }
 
@@ -740,6 +723,14 @@ static inline NSRect integralRect (NSRect rect, NSView *view)
     }
 }
 
+- (void) setNextKeyView: (NSView *)aView
+{
+  if (_documentView && aView != _documentView)
+    [_documentView setNextKeyView: aView];
+  else
+    [super setNextKeyView: aView];
+}
+
 /*
  * NSCoding protocol
  */
