@@ -121,6 +121,7 @@
   NSMenu *_the_menu;
 }
 - (void) _setmenu: (NSMenu *)menu;
+- (NSMenu *) _menu;
 @end
 
 @interface NSMenuView (GNUstepPrivate)
@@ -155,6 +156,10 @@ static BOOL menuBarVisible = YES;
 {
   _the_menu = menu;
 }
+- (NSMenu *) _menu
+{
+    return _the_menu;
+}
 
 - (BOOL) canBecomeKeyWindow
 {
