@@ -50,9 +50,9 @@
 @implementation _NSManagedProxy
 - (id) initWithCoder: (NSCoder *)coder
 {
-  if((self = [super init]) != nil)
+  if ((self = [super init]) != nil)
     {
-      if([coder allowsKeyedCoding])
+      if ([coder allowsKeyedCoding])
 	{
 	  ASSIGN(_entity_name_key,[coder decodeObjectForKey: @"NSEntityName"]);
 	}
@@ -66,7 +66,7 @@
 
 - (void) encodeWithCoder: (NSCoder *)coder
 {
-  if([coder allowsKeyedCoding])
+  if ([coder allowsKeyedCoding])
     {
       [coder encodeObject: _entity_name_key forKey: @"NSEntityName"];
     }
@@ -104,8 +104,10 @@
             triggerChangeNotificationsForDependentKey: @"canAdd"];
       [self setKeys: [NSArray arrayWithObject: @"editable"] 
             triggerChangeNotificationsForDependentKey: @"canRemove"];
-      [self setKeys: [NSArray arrayWithObject: @"content"] 
+      [self setKeys: [NSArray arrayWithObjects: @"content", NSContentObjectBinding, nil] 
             triggerChangeNotificationsForDependentKey: @"selectedObjects"];
+      [self setKeys: [NSArray arrayWithObjects: @"content", NSContentObjectBinding, nil] 
+            triggerChangeNotificationsForDependentKey: @"selection"];
     }
 }
 
@@ -140,11 +142,13 @@
 - (void) encodeWithCoder: (NSCoder *)coder
 { 
   [super encodeWithCoder: coder];
-  if([coder allowsKeyedCoding])
+  if ([coder allowsKeyedCoding])
     {
       [coder encodeBool: _is_editable forKey: @"NSEditable"];
       [coder encodeBool: _automatically_prepares_content forKey: @"NSAutomaticallyPreparesContent"];
       [coder encodeObject: _managed_proxy forKey: @"_NSManagedProxy"];
+      [coder encodeObject: NSStringFromClass([self objectClass])
+                   forKey: @"NSObjectClassName"];
     }
   else
     {
@@ -156,7 +160,7 @@
 
 - (id) initWithCoder: (NSCoder *)coder
 { 
-  if((self = [super initWithCoder: coder]) != nil)
+  if ((self = [super initWithCoder: coder]) != nil)
     {
       if ([self automaticallyPreparesContent])
 	{
@@ -170,11 +174,16 @@
 	    }
 	}
       
-      if([coder allowsKeyedCoding])
+      if ([coder allowsKeyedCoding])
 	{
 	  _is_editable = [coder decodeBoolForKey: @"NSEditable"];
 	  _automatically_prepares_content = [coder decodeBoolForKey: @"NSAutomaticallyPreparesContent"];
 	  ASSIGN(_managed_proxy, [coder decodeObjectForKey: @"_NSManagedProxy"]);
+          if ([coder containsValueForKey: @"NSObjectClassName"])
+            {
+              NSString *className = [coder decodeObjectForKey: @"NSObjectClassName"];
+              [self setObjectClass: NSClassFromString(className)];
+            }
 	}
       else
 	{
@@ -194,19 +203,22 @@
 
 - (void) setContent: (id)content
 {
-  NSMutableArray *selection;
+  if (content != _content)
+    {
+      NSMutableArray *selection;
 
-  ASSIGN(_content, content);
-  if (content)
-    {
-        selection = [[NSMutableArray alloc] initWithObjects: &content count: 1];
+      ASSIGN(_content, content);
+      if (content)
+        {
+          selection = [[NSMutableArray alloc] initWithObjects: &content count: 1];
+        }
+      else
+        {
+          selection = [[NSMutableArray alloc] init];
+        }
+      ASSIGN(_selection, selection);
+      RELEASE(selection);
     }
-  else
-    {
-      selection = [[NSMutableArray alloc] init];
-    }
-  ASSIGN(_selection, selection);
-  RELEASE(selection);
 }
 
 - (void)bind: (NSString *)binding 
@@ -214,7 +226,7 @@
  withKeyPath: (NSString *)keyPath
      options: (NSDictionary *)options
 {
-  if ([binding isEqual:NSContentObjectBinding])
+  if ([binding isEqual: NSContentObjectBinding])
     {
       GSKeyValueBinding *kvb;
 
@@ -283,16 +295,13 @@
 
 - (void) addObject: (id)obj
 {
-  NSDictionary * bindingInfo = [self infoForBinding: NSContentObjectBinding];
+  GSKeyValueBinding *theBinding;
 
   [self setContent: obj];
-  if (bindingInfo)
-    {
-      // Change the relationship of the object that our content is bound to.
-      id masterObject = [bindingInfo objectForKey: NSObservedObjectKey];
-      NSString * keyPath = [bindingInfo objectForKey: NSObservedKeyPathKey];
-      [masterObject setValue: obj forKeyPath: keyPath];
-    }
+  theBinding = [GSKeyValueBinding getBinding: NSContentObjectBinding 
+                                   forObject: self];
+  if (theBinding != nil)
+    [theBinding reverseSetValueFor: @"content"];
 }
 
 - (void) remove: (id)sender
@@ -307,16 +316,13 @@
 {
   if (obj == [self content])
     {
-      NSDictionary * bindingInfo = [self infoForBinding: NSContentObjectBinding];
+      GSKeyValueBinding *theBinding;
 
       [self setContent: nil];
-      if (bindingInfo)
-        {
-          // Change the relationship of the object that our content is bound to.
-          id masterObject = [bindingInfo objectForKey: NSObservedObjectKey];
-          NSString * keyPath = [bindingInfo objectForKey: NSObservedKeyPathKey];
-          [masterObject setValue: nil forKeyPath: keyPath];
-        }
+      theBinding = [GSKeyValueBinding getBinding: NSContentObjectBinding 
+                                       forObject: self];
+      if (theBinding != nil)
+        [theBinding reverseSetValueFor: @"content"];
     }
 }
 
@@ -349,13 +355,13 @@
 - (id) selection
 {
   // TODO
-  return nil;
+  return _content;
 }
 
 
 - (BOOL) validateMenuItem: (id <NSMenuItem>)item
 {
-  SEL  action = [item action];
+  SEL action = [item action];
 
   if (sel_isEqual(action, @selector(add:)))
     {
