@@ -1,6 +1,7 @@
 
-#include <Foundation/Foundation.h>
-#include "AppKit/AppKit.h"
+#import <Foundation/Foundation.h>
+#import "AppKit/AppKit.h"
+#import "GNUstepGUI/GSFontInfo.h"
 
 void __objc_gui_linking(void)
 {
